@@ -24,7 +24,7 @@
 #include "details_designer.h"
 
 class Details : public DetailsDesigner {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
