@@ -35,7 +35,7 @@ class KMFError;
 @author Christian Hubinger
 */
 
-class KDE_EXPORT KMFPlugin : public KParts::Plugin {
+class TDE_EXPORT KMFPlugin : public KParts::Plugin {
 public:
 	KMFPlugin( TQObject* parent , const char* name  );
     virtual ~KMFPlugin();
