@@ -17,13 +17,13 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 /**
 @author Christian Hubinger
 */
 namespace KMF {
-class KDE_EXPORT KMFRuleTargetOptionEditInterface : public KMFRuleOptionEditInterface {
+class TDE_EXPORT KMFRuleTargetOptionEditInterface : public KMFRuleOptionEditInterface {
 public:
 	KMFRuleTargetOptionEditInterface(TQObject *parent = 0, const char *name = 0);
 
