@@ -18,7 +18,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 #include <tqlabel.h>
 
 // KDE includes
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
 #include <tdelocale.h>
