@@ -29,7 +29,7 @@ class KMFMainWindow;
 class KMFGenericInterface;
 
 class KMFGenericInterfacePart: public KParts::ReadWritePart {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFGenericInterfacePart( TQWidget *parent, const char *name, TQObject *parentObject, const
@@ -93,7 +93,7 @@ private:
 
 class KMFGenericInterfacePartFactory : public KParts::Factory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMFGenericInterfacePartFactory();
