@@ -22,7 +22,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 #include <tqdatetime.h>
 
 // KDE includes
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
 #include <tdefiledialog.h>
