@@ -46,7 +46,7 @@ class KMFErrorHandler;
 class KMFCompilerInterface;
 
 class KMFIPTInstaller :  public KMFPlugin, public KMFInstallerInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -125,13 +125,13 @@ signals:
 
 
 class KMFIPTInstallerFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFIPTInstallerFactory( TQObject *parent = 0, const char *name = 0 );
 	virtual ~KMFIPTInstallerFactory() {};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 };
 }
