@@ -1121,7 +1121,7 @@ TQObject* KMFPFInstallerFactory::createObject( TQObject* parent, const char* nam
 // }
 
 extern "C" {
-	void* init_libkmfinstaller_openbsd() {
+	TDE_EXPORT void* init_libkmfinstaller_openbsd() {
 		return new KMFPFInstallerFactory;
 	}
 }
