@@ -26,7 +26,7 @@
 
 namespace KMF {
 class KMFChainEdit : public KMyFirewallChainEditor {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFChainEdit( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
