@@ -20,7 +20,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001
 
 
 // KDE includes
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
 #include <tdeaccel.h>
