@@ -28,7 +28,7 @@ class IPTable;
 */
 class KMFIPTDocView : public TQTabWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     KMFIPTDocView(TQWidget *parent = 0, const char *name = 0);
