@@ -543,7 +543,7 @@ void KMFListView::setupChainView( IPTChain* chain, KMFListViewItem* parent ) {
 	i_chain_allrules = findKMFItem( i18n( "Rule(s):" ), 0, chain->uuid(), true, item );
 	if ( ! i_chain_allrules ) {
 		i_chain_allrules = new KMFListViewItem( item, i_chain_fwds, chain );
-		i_chain_allrules->setOpen( TRUE );
+		i_chain_allrules->setOpen( true );
 	}
 	i_chain_allrules->sortChildItems( 0, true );
 
