@@ -13,7 +13,7 @@
 
 #include "kmfselectactivetarget.h"
 
-// QT includes
+// TQt includes
 #include <tqstring.h>
 #include <tqcheckbox.h>
 #include <tqfile.h>
@@ -89,16 +89,16 @@ KMFSelectActiveTarget::KMFSelectActiveTarget ( TQWidget* parent, const char* nam
 {
 	m_cmd_ok->setEnabled( false );	
 	
-	connect( m_lv_zones, TQT_SIGNAL( pressed( TQListViewItem* ) ) ,
-		 this, TQT_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
+	connect( m_lv_zones, TQ_SIGNAL( pressed( TQListViewItem* ) ) ,
+		 this, TQ_SLOT( slotNewItemSelected( TQListViewItem* ) ) );
 	
-	connect( m_lv_zones, TQT_SIGNAL( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ) ,
-		 this, TQT_SLOT( slotNewItemDBLClicked( TQListViewItem*, const TQPoint &, int  ) ) );	 
+	connect( m_lv_zones, TQ_SIGNAL( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ) ,
+		 this, TQ_SLOT( slotNewItemDBLClicked( TQListViewItem*, const TQPoint &, int  ) ) );	 
 	
-	connect( m_cmd_cancel, TQT_SIGNAL( clicked() ) ,
-		 this, TQT_SLOT( slotCancel() ) );	 
-	connect( m_cmd_ok, TQT_SIGNAL( clicked() ) ,
-		 this, TQT_SLOT( slotOk() ) );
+	connect( m_cmd_cancel, TQ_SIGNAL( clicked() ) ,
+		 this, TQ_SLOT( slotCancel() ) );	 
+	connect( m_cmd_ok, TQ_SIGNAL( clicked() ) ,
+		 this, TQ_SLOT( slotOk() ) );
 		 
 	adjustSize();
 }
