@@ -19,13 +19,13 @@
 #include <tqstringlist.h>
 
 // KDE Includes
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 // Project Includes
 
 
 namespace KMF {
-class KDE_EXPORT KMFSelectInterface : public KMyFirewallSelectInterface {
+class TDE_EXPORT KMFSelectInterface : public KMyFirewallSelectInterface {
 	TQ_OBJECT
   
 
