@@ -12,7 +12,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 */
 #include "kmyfirewall.h"
 
-// QT includes
+// TQt includes
 #include <tqmessagebox.h>
 #include <tqtextstream.h>
 #include <tqpixmap.h>
@@ -97,11 +97,11 @@ KMyFirewall::KMyFirewall( TQWidget* parent, const char *name ) : KMFMainWindow(
 	
 /*	childproc = new TDEProcess();
 	
-	connect( childproc, TQT_SIGNAL( processExited( TDEProcess* ) ), TQT_TQOBJECT(this), TQT_SLOT( slotProcessExited( TDEProcess* ) ) ) ;
+	connect( childproc, TQ_SIGNAL( processExited( TDEProcess* ) ), this, TQ_SLOT( slotProcessExited( TDEProcess* ) ) ) ;
 	
-	connect( childproc, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedOutput( TDEProcess*, char*, int ) ) );
+	connect( childproc, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), this, TQ_SLOT( slotReceivedOutput( TDEProcess*, char*, int ) ) );
 	
-	connect( childproc, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQT_TQOBJECT(this), TQT_SLOT( slotReceivedError( TDEProcess*, char*, int ) ) );*/
+	connect( childproc, TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), this, TQ_SLOT( slotReceivedError( TDEProcess*, char*, int ) ) );*/
 	
 	
 	
@@ -110,8 +110,8 @@ KMyFirewall::KMyFirewall( TQWidget* parent, const char *name ) : KMFMainWindow(
 	// Initialize the settings dialog
 	m_configDlg = new KMFConfigDialog( this, "config" );
 	m_configDlg->setNetwork( network() );	
-	connect ( m_configDlg, TQT_SIGNAL( sigConfigChanged() ),
-	          TQT_TQOBJECT(this), TQT_SLOT( slotConfigChanged() ) );
+	connect ( m_configDlg, TQ_SIGNAL( sigConfigChanged() ),
+	          this, TQ_SLOT( slotConfigChanged() ) );
 
 	// Initialize error object
 	m_err = new KMFError();
@@ -287,8 +287,8 @@ void KMyFirewall::setOutputWidget( TQWidget* wid ) {
 	kdDebug() << "Adding outputwidget: " << wid->className() << endl;
 	if ( strcmp(wid->className(), "KMFObjectInfo") ) {
 		KPushButton * close = new KPushButton( i18n( "Return to Editor View" ), widget );
-		connect( close, TQT_SIGNAL( clicked() ),
-		         TQT_TQOBJECT(this), TQT_SLOT( slotShowEditor() ) );
+		connect( close, TQ_SIGNAL( clicked() ),
+		         this, TQ_SLOT( slotShowEditor() ) );
 		layout->addWidget( close, 1, 0 );
 	}
 	m_outputWidget = widget;
@@ -299,50 +299,50 @@ void KMyFirewall::initActions() {
 	kdDebug() << "Init Actions..." << endl;
 	// Custom Actions
 
-	actionEditDocInfo = new TDEAction( i18n( "&Edit Document Information" ), "edit", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotEditDocInfo() ), actionCollection(), "edit_doc_info" );
+	actionEditDocInfo = new TDEAction( i18n( "&Edit Document Information" ), "edit", 0 , this, TQ_SLOT( slotEditDocInfo() ), actionCollection(), "edit_doc_info" );
 
 	// KStdAction
-	actionNew = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT( slotFileNew() ),
+	actionNew = KStdAction::openNew( this, TQ_SLOT( slotFileNew() ),
 	                                 actionCollection(), "new" );
 
-	actionClose = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( slotFileClose() ),
+	actionClose = KStdAction::close( this, TQ_SLOT( slotFileClose() ),
 	                                 actionCollection(), "close" );
 
-	actionOpen = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT( slotFileOpen() ),
+	actionOpen = KStdAction::open( this, TQ_SLOT( slotFileOpen() ),
 	                               actionCollection(), "open" );
 
-	actionSave = KStdAction::save( TQT_TQOBJECT(this), TQT_SLOT( slotFileSave() ),
+	actionSave = KStdAction::save( this, TQ_SLOT( slotFileSave() ),
 	                               actionCollection(), "save" );
 
-	actionSaveAs = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT( slotFileSaveAs() ),
+	actionSaveAs = KStdAction::saveAs( this, TQ_SLOT( slotFileSaveAs() ),
 	                                   actionCollection(), "save_as" );
 	actionSaveAs->setEnabled( false );
 
-	actionQuit = KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( slotQuitApp() ),
+	actionQuit = KStdAction::quit( this, TQ_SLOT( slotQuitApp() ),
 	                               actionCollection(), "quit" );
 
-	actionUndo = KStdAction::undo( TQT_TQOBJECT(this), TQT_SLOT( slotUndo() ),
+	actionUndo = KStdAction::undo( this, TQ_SLOT( slotUndo() ),
 	                               actionCollection(), "undo" );
 
-	actionRedo = KStdAction::redo( TQT_TQOBJECT(this), TQT_SLOT( slotRedo() ),
+	actionRedo = KStdAction::redo( this, TQ_SLOT( slotRedo() ),
 	                               actionCollection(), "redo" );
 
-	actionExportTargetConfig = new TDEAction( i18n( "&Export Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotExportTargetConfig() ),
+	actionExportTargetConfig = new TDEAction( i18n( "&Export Target Configuration..." ), "wizard", 0 , this, TQ_SLOT( slotExportTargetConfig() ),
 	                                  actionCollection(), "export_tagret_config" );
 	
-	actionImportTargetConfig = new TDEAction( i18n( "&Import Target Configuration..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotImportTargetConfig() ), 
+	actionImportTargetConfig = new TDEAction( i18n( "&Import Target Configuration..." ), "wizard", 0 , this, TQ_SLOT( slotImportTargetConfig() ), 
 	                                  actionCollection(), "import_tagret_config" );
 	
-	actionShowTransactionLog = new TDEAction( i18n( "&Show Transaction Log..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotShowTransactionLog() ),
+	actionShowTransactionLog = new TDEAction( i18n( "&Show Transaction Log..." ), "wizard", 0 , this, TQ_SLOT( slotShowTransactionLog() ),
 	                                  actionCollection(), "show_transaction_log" );
 	
-	actionLoadTemplate = new TDEAction( i18n( "&Load Template..." ), "wizard", 0 , TQT_TQOBJECT(this), TQT_SLOT( slotLoadTemplate() ),
+	actionLoadTemplate = new TDEAction( i18n( "&Load Template..." ), "wizard", 0 , this, TQ_SLOT( slotLoadTemplate() ),
 	                                  actionCollection(), "load_template" );
 	                                  
-//	KStdAction::showToolbar( TQT_TQOBJECT(this), TQT_SLOT( toggleToolBar() ) , actionCollection() );
-	KStdAction::showStatusbar( TQT_TQOBJECT(this), TQT_SLOT( toggleStatusBar() ), actionCollection() );
-	KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT( slotConfigureKMF() ), actionCollection() );
-	KStdAction::configureToolbars( TQT_TQOBJECT(this), TQT_SLOT( slotConfigureToolbars() ), actionCollection() );
+//	KStdAction::showToolbar( this, TQ_SLOT( toggleToolBar() ) , actionCollection() );
+	KStdAction::showStatusbar( this, TQ_SLOT( toggleStatusBar() ), actionCollection() );
+	KStdAction::preferences( this, TQ_SLOT( slotConfigureKMF() ), actionCollection() );
+	KStdAction::configureToolbars( this, TQ_SLOT( slotConfigureToolbars() ), actionCollection() );
 }
 
 
@@ -362,7 +362,7 @@ void KMyFirewall::slotExportTargetConfig() {
 void KMyFirewall::slotConfigureToolbars() {
 	saveMainWindowSettings( TDEGlobal::config(), "KMyFirewall" );
 	KEditToolbar dlg( factory() );
-	connect( &dlg, TQT_SIGNAL( newToolbarConfig() ), TQT_TQOBJECT(this), TQT_SLOT( slotNewToolbarConfig() ) );
+	connect( &dlg, TQ_SIGNAL( newToolbarConfig() ), this, TQ_SLOT( slotNewToolbarConfig() ) );
 	dlg.exec();
 }
 
@@ -491,7 +491,7 @@ void KMyFirewall::slotEnableSave() {
 void KMyFirewall::slotEditDocInfo() {
 	KMFDocumentInfo * dlg = new KMFDocumentInfo( this, "KMFObjectInfo", true );
 	dlg->loadDoc( network()->currentDoc() );
-	connect( dlg,TQT_SIGNAL( sigSaveAsTemplate() ) , TQT_TQOBJECT(this), TQT_SLOT( slotFileSaveAsTemplate() )  );
+	connect( dlg,TQ_SIGNAL( sigSaveAsTemplate() ) , this, TQ_SLOT( slotFileSaveAsTemplate() )  );
 	dlg->exec();
 }
 
@@ -579,10 +579,10 @@ void KMyFirewall::slotLoadTemplate() {
 	KMFTemplateChooser * dlg = new KMFTemplateChooser( 0 , "KMyFirewall - Load Template", true, TQWidget::WDestructiveClose | TQWidget::WStyle_Customize | TQWidget::WStyle_NoBorder );
 	
 	// dlg->parseTemplates();
-	connect( dlg, TQT_SIGNAL( sigLoadTemplate( const TQString& ) ),
-	         TQT_TQOBJECT(this), TQT_SLOT( slotLoadFile( const TQString& ) ) );
-/*	connect( dlg, TQT_SIGNAL( sigLoadEmptyDocument() ),
-	         TQT_TQOBJECT(this), TQT_SLOT( slotLoadFile( const TQString& ) ) );*/
+	connect( dlg, TQ_SIGNAL( sigLoadTemplate( const TQString& ) ),
+	         this, TQ_SLOT( slotLoadFile( const TQString& ) ) );
+/*	connect( dlg, TQ_SIGNAL( sigLoadEmptyDocument() ),
+	         this, TQ_SLOT( slotLoadFile( const TQString& ) ) );*/
 	dlg->exec();
 }
 
@@ -921,9 +921,9 @@ void KMyFirewall::slotFileNew() {
 	KMFNewDocDlg *dlg = new KMFNewDocDlg( 0, "KMyFirewall - New Document", TQWidget::WDestructiveClose | TQWidget::WStyle_Customize | TQWidget::WStyle_NoBorder );
 	dlg->show() ;
 	dlg->raise();
-	connect( dlg, TQT_SIGNAL( sigNewDocLoadTemplate() ), TQT_TQOBJECT(this), TQT_SLOT( slotLoadTemplate() ) );
-	connect( dlg, TQT_SIGNAL( sigNewDocLoadEmpty() ), TQT_TQOBJECT(this), TQT_SLOT( slotLoadEmptyRuleset() ) );
-	connect( dlg, TQT_SIGNAL( sigNewDocLoadSaved() ), TQT_TQOBJECT(this), TQT_SLOT( slotFileOpen() ) );
+	connect( dlg, TQ_SIGNAL( sigNewDocLoadTemplate() ), this, TQ_SLOT( slotLoadTemplate() ) );
+	connect( dlg, TQ_SIGNAL( sigNewDocLoadEmpty() ), this, TQ_SLOT( slotLoadEmptyRuleset() ) );
+	connect( dlg, TQ_SIGNAL( sigNewDocLoadSaved() ), this, TQ_SLOT( slotFileOpen() ) );
 }
 
 void KMyFirewall::slotLoadEmptyRuleset() {
