@@ -119,7 +119,7 @@ TQObject* KMFRuleOptionEditCustomFactory::createObject( TQObject* parent, const
 // // }
 
 extern "C" {
-	void* init_libkmfruleoptionedit_custom() {
+	TDE_EXPORT void* init_libkmfruleoptionedit_custom() {
 		return new KMFRuleOptionEditCustomFactory;
 	}
 }
