@@ -26,7 +26,7 @@
 class IPTRule;
 
 class KMFRuleEditorLimit : public KMyFirewallRuleEditorLimit {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditorLimit( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
