@@ -27,7 +27,7 @@ class KMFRuleEditTargetLog;
 @author Christian Hubinger
 */
 class KMFRuleTargetOptionEditLog : public KMFRuleTargetOptionEditInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleTargetOptionEditLog(TQObject *parent = 0, const char *name = 0);
@@ -51,7 +51,7 @@ private:
 
 
 class KMFRuleTargetOptionEditLogFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleTargetOptionEditLogFactory( TQObject *parent = 0, const char *name = 0 );
@@ -59,7 +59,7 @@ public:
 /* 		delete s_instance; */
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 	/*     static TDEInstance* instance(); */
 
