@@ -32,7 +32,7 @@ class IPTRule;
 
 
 class KMFRuleEditorProtocol : public KMyFirewallRuleEditorProtocol {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditorProtocol( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
