@@ -25,7 +25,7 @@ class IPTRule;
   */
 
 class KMFRuleEditorState : public KMyFirewallRuleEditorState {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleEditorState( TQWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
