@@ -39,7 +39,7 @@ class KMFRuleEditorState;
 @author Christian Hubinger
 */
 class KMFRuleOptionEditState : public KMFRuleOptionEditInterface {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleOptionEditState(TQObject *parent = 0, const char *name = 0);
@@ -62,7 +62,7 @@ private:
 
 
 class KMFRuleOptionEditStateFactory : public KLibFactory {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KMFRuleOptionEditStateFactory( TQObject *parent = 0, const char *name = 0 );
@@ -70,7 +70,7 @@ public:
 /* 		delete s_instance; */
 	};
 	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
-	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
+	                               const char* name = "TQObject",
 	                               const TQStringList &args = TQStringList() );
 	/*     static TDEInstance* instance(); */
 
